enum SetBlockMode {
Destroy,
Keep,
Replace,
Strict,
}Expand description
How the block should be placed
Variants
Destroy
Destroy the previous block and drop the loot according to the loot table
Keep
Can only place a block if the previous block was air
Replace
Base case
Strict
Replace the block without updating the world